# Plutis CLI v1.0.0

We make it easy for you to orchestrate underlying infrastrucutre for your AI applications.

Our selling point is very simple: you build YAML files and we orchestrate. Easily spin up data pipelines and data stores as well as monitoring tools with one CLI. Create end-to-end applications without worrying about developing internal tools for orchestration.